<div align="center">
  <img src="https://raw.githubusercontent.com/Edenskull/KleenLogger/master/.github/_static/KleenLogger.jpg">
</div>

<div align="center">

[![GitHub license](https://img.shields.io/github/license/Edenskull/KleenLogger?color=blue&style=for-the-badge)](https://github.com/Edenskull/KleenLogger/blob/master/LICENSE)
![GitHub repo size](https://img.shields.io/github/repo-size/Edenskull/KleenLogger?color=green&style=for-the-badge)
![GitHub repo size](https://img.shields.io/badge/Python-3.6%20%7C%203.7-yellow?style=for-the-badge)

</div>

# Kleen-Logger
Simple python library that handle Logging of a script.

## Table of contents
* [Installation](#installation)
* [Documentation](#documentation)

## Installation


## Documentation

Soon
